/*!
 * @header Utils
 * Useful or unifying constants and macros.
 */

#ifndef __UTILS__
#define __UTILS__

/*!
 * @enum exn_code
 * Exception classifications according to origin.
 */
enum exn_code {
  EXN_CODE_ANY,
  EXN_CODE_STDLIB,
  EXN_CODE_PVM,
  EXN_CODE_NETCDF
} ;

/*!
 * @enum msg
 * Message IDs that are commonly used.
 */
enum msg {
  MSG_CONFIG,
  MSG_DATA
} ;

/*!
 * @enum dir
 * A definition of indices for the main geographical directions.
 */
enum dir {
  DIR_NORTH,
  DIR_EAST,
  DIR_SOUTH,
  DIR_WEST
} ;

/*!
 * @define NEW
 * Convenient structure allocation macro. Uses malloc, so the memory you get
 * is uninitialized.
 * @param type datatype of structure
 */
#define NEW(type) ((type *)malloc(sizeof(type)))

/*!
 * @define NEWARRAY
 * Convenient array allocation macro. Uses calloc, so the array you get
 * is cleared to zero bytes.
 * @param type datatype of array elements
 * @param count number of array elements
 */
#define NEWARRAY(type, count) ((type *)calloc((count), sizeof(type)))

#endif /* __UTILS__ */

/* vim:set shiftwidth=2 softtabstop=2: */
